Index: pjproject/trunk/pjsip/include/pjsua-lib/getopt.h
===================================================================
--- pjproject/trunk/pjsip/include/pjsua-lib/getopt.h	(revision 238)
+++ pjproject/trunk/pjsip/include/pjsua-lib/getopt.h	(revision 300)
@@ -1,5 +1,5 @@
 /* $Id$ */
 /* This file has now become GPL. */
-/* Declarations for getopt.
+/* Declarations for pj_getopt.
    Copyright (C) 1989,90,91,92,93,94,96,97,98 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
@@ -20,6 +20,6 @@
    Boston, MA 02111-1307, USA.  */
 
-#ifndef _GETOPT_H
-#define _GETOPT_H 1
+#ifndef __PJ_GETOPT_H__
+#define __PJ_GETOPT_H__ 1
 
 #ifdef	__cplusplus
@@ -27,38 +27,38 @@
 #endif
 
-/* For communication from `getopt' to the caller.
-   When `getopt' finds an option that takes an argument,
+/* For communication from `pj_getopt' to the caller.
+   When `pj_getopt' finds an option that takes an argument,
    the argument value is returned here.
    Also, when `ordering' is RETURN_IN_ORDER,
    each non-option ARGV-element is returned here.  */
 
-extern char *optarg;
+extern char *pj_optarg;
 
 /* Index in ARGV of the next element to be scanned.
    This is used for communication to and from the caller
-   and for communication between successive calls to `getopt'.
+   and for communication between successive calls to `pj_getopt'.
 
-   On entry to `getopt', zero means this is the first call; initialize.
+   On entry to `pj_getopt', zero means this is the first call; initialize.
 
-   When `getopt' returns -1, this is the index of the first of the
+   When `pj_getopt' returns -1, this is the index of the first of the
    non-option elements that the caller should itself scan.
 
-   Otherwise, `optind' communicates from one call to the next
+   Otherwise, `pj_optind' communicates from one call to the next
    how much of ARGV has been scanned so far.  */
 
-extern int optind;
+extern int pj_optind;
 
 /* Callers store zero here to inhibit the error message `getopt' prints
    for unrecognized options.  */
 
-extern int opterr;
+extern int pj_opterr;
 
 /* Set to an option character which was unrecognized.  */
 
-extern int optopt;
+extern int pj_optopt;
 
 /* Describe the long-named options requested by the application.
-   The LONG_OPTIONS argument to getopt_long or getopt_long_only is a vector
-   of `struct option' terminated by an element containing a name which is
+   The LONG_OPTIONS argument to pj_getopt_long or pj_getopt_long_only is a vector
+   of `struct pj_getopt_option' terminated by an element containing a name which is
    zero.
 
@@ -73,11 +73,11 @@
 
    To have a long-named option do something other than set an `int' to
-   a compiled-in constant, such as set a value from `optarg', set the
+   a compiled-in constant, such as set a value from `pj_optarg', set the
    option's `flag' field to zero and its `val' field to a nonzero
    value (the equivalent single-letter option character, if there is
-   one).  For long options that have a zero `flag' field, `getopt'
+   one).  For long options that have a zero `flag' field, `pj_getopt'
    returns the contents of the `val' field.  */
 
-struct option
+struct pj_getopt_option
 {
   const char *name;
@@ -89,5 +89,5 @@
 };
 
 /* Names for the values of the `has_arg' field of `struct option'.  */
 
 # define no_argument		0
@@ -102,29 +102,29 @@
    Return the option character from OPTS just read.  Return -1 when
    there are no more options.  For unrecognized options, or options
-   missing arguments, `optopt' is set to the option letter, and '?' is
+   missing arguments, `pj_optopt' is set to the option letter, and '?' is
    returned.
 
    The OPTS string is a list of characters which are recognized option
    letters, optionally followed by colons, specifying that that letter
-   takes an argument, to be placed in `optarg'.
+   takes an argument, to be placed in `pj_optarg'.
 
    If a letter in OPTS is followed by two colons, its argument is
-   optional.  This behavior is specific to the GNU `getopt'.
+   optional.  This behavior is specific to the GNU `pj_getopt'.
 
    The argument `--' causes premature termination of argument
-   scanning, explicitly telling `getopt' that there are no more
+   scanning, explicitly telling `pj_getopt' that there are no more
    options.
 
    If OPTS begins with `--', then non-option arguments are treated as
    arguments to the option '\0'.  This behavior is specific to the GNU
-   `getopt'.  */
+   `pj_getopt'.  */
 
-int getopt (int argc, char *const *argv, const char *shortopts);
+int pj_getopt (int argc, char *const *argv, const char *shortopts);
 
-int getopt_long (int argc, char *const *argv, const char *options,
-		        const struct option *longopts, int *longind);
-int getopt_long_only (int argc, char *const *argv,
+int pj_getopt_long (int argc, char *const *argv, const char *options,
+		        const struct pj_getopt_option *longopts, int *longind);
+int pj_getopt_long_only (int argc, char *const *argv,
 			     const char *shortopts,
-		             const struct option *longopts, int *longind);
+		             const struct pj_getopt_option *longopts, int *longind);
 
 
@@ -133,4 +133,4 @@
 #endif
 
-#endif /* getopt.h */
+#endif /* pj_getopt.h */
 
@@ -27,38 +27,38 @@
 
-/* Callers store zero here to inhibit the error message `getopt' prints
+/* Callers store zero here to inhibit the error message `pj_getopt' prints
    for unrecognized options.  */
 
@@ -89,5 +89,5 @@
 };
 
-/* Names for the values of the `has_arg' field of `struct option'.  */
+/* Names for the values of the `has_arg' field of `struct pj_getopt_option'.  */
 
 # define no_argument		0
